@@ -1,10 +1,10 @@
+#include <config.h>
 #include <gnome.h>
 #include <gtk/gtk.h>
 
 #include "makros.h"
 #include "var.h"
 #include "pro.h"
-#include "version.h"
 #include "partie.h"
 #include "disk.h"
 #include "menu.h"
@@ -39,19 +39,17 @@ about_cb (GtkWidget *widget, void *data)
 {
   GtkWidget *about;
   const  gchar *authors[] = {
-	  "Robert Wilhelm <robert@physiol.med.tu-muenchen.de>",
+	  N_("Robert Wilhelm <robert@physiol.med.tu-muenchen.de>"),
           NULL
           };
 
-  char *comments = "This  program  is  part of  the  GNOME  project. " 
-" Gnome-Chess comes with ABSOLUTELY NO WARRANTY. This is free " 
-"software, and you are welcome to redistribute it under the conditions "
-"of the GNU General Public Licence.";
-
-  about = gnome_about_new ( "The Gnome Chess Program", VERSION,
-			    "Copyright (C) 1998",
+  about = gnome_about_new ( _("The Gnome Chess Program"), VERSION,
+			    _("Copyright (C) 1998"),
 			    authors,
-			    comments,
+  		_("This  program  is  part of  the  GNOME  project. " 
+	" Gnome-Chess comes with ABSOLUTELY NO WARRANTY. This is free " 
+	"software, and you are welcome to redistribute it under the conditions "
+	"of the GNU General Public Licence."),
 			    NULL);
   gtk_widget_show (about);
   return;
@@ -230,7 +228,7 @@ static int press(GnomeCanvasItem *item, GdkEvent *event, gpointer data)
 
 GtkWidget * init_board(void)
 {
-  static char *titles[] ={ _("Number"),_("White"),_("Black")};
+  static char *titles[] ={ N_("Number"),N_("White"),N_("Black")};
   GtkWidget *table;
   GtkWidget *scrolled_window;
   int i;
@@ -244,6 +242,11 @@ GtkWidget * init_board(void)
 
 
   scrolled_window =gtk_scrolled_window_new (NULL, NULL);
+#ifdef ENABLE_NLS
+  titles[0]=_(titles[0]);
+  titles[1]=_(titles[1]);
+  titles[2]=_(titles[2]);
+#endif
   board.movelist = gtk_clist_new_with_titles(3,titles);
   //  gtk_clist_set_row_height (GTK_CLIST (board.movelist), 18);
   gtk_clist_set_selection_mode(GTK_CLIST (board.movelist),GTK_SELECTION_BROWSE);
