@@ -11,7 +11,6 @@
 #include "makros.h"
 #include "var.h"
 #include "pro.h"
-#include "version.h"
 #include "menu.h"
 #include "child.h"
 #include "board.h"
@@ -30,6 +29,22 @@
 
 struct engine *first_chess_programm;
 
+/* The debugging level */
+int debugging = 0;
+
+static char *fcp = NULL;
+static char **startup_files = NULL;
+
+static poptContext ctx;
+
+static const struct poptOption gnome_chess_popt_options [] = {
+	{ "fcp", '\0', POPT_ARG_STRING, &fcp, 0,
+	  N_("First Chess Programm"),   N_("FILE") },
+	{ "debug", '\0', POPT_ARG_INT, &debugging, 0,
+	  N_("Enables some debugging functions"), N_("LEVEL") },
+	{ NULL, '\0', 0, NULL, 0 }
+};
+
 int main(int argc,char *argv[])
 {
      GtkWidget *box;
@@ -38,20 +53,23 @@ int main(int argc,char *argv[])
      bindtextdomain (PACKAGE, GNOMELOCALEDIR);
      textdomain (PACKAGE);
 
-     gnome_init ("chess", VERSION, argc, argv);
-
+     gnome_init_with_popt_table ("chess", VERSION, argc, argv, gnome_chess_popt_options,0, &ctx);
 
      ini_chessboard();
 
      //     pgn_test(); 
      //return 0;
 
-     app = gnome_app_new ("chess", "Gnomified chess program");
+     app = gnome_app_new ("chess", _("Gnomified chess program"));
 
      create_menus(app);
-	
-     first_chess_programm =new_engine(FIRST_CHESS_PROGRAMM,FIRST_CHESS_PROGRAMM_ARG);
+
+     if(fcp)
+     first_chess_programm = new_engine(fcp,NULL);
+     else
+     first_chess_programm = new_engine(FIRST_CHESS_PROGRAMM,FIRST_CHESS_PROGRAMM_ARG);
      //     engine_write(first_chess_programm,"log off\n");
+     engine_write(first_chess_programm,"xboard\n");
      engine_write(first_chess_programm,"post\n");
      engine_write(first_chess_programm,"easy\n");
      engine_write(first_chess_programm,"level 60 2 0\n");
@@ -62,7 +80,12 @@ int main(int argc,char *argv[])
      gtk_widget_show(box);
      gtk_widget_show (app);
 
-     if (argc>1) pgn_open(argv[1]);
+     startup_files = poptGetArgs (ctx);
+     if (startup_files) 
+       pgn_open(startup_files);
+     
+     poptFreeContext (ctx);
+
 
      gtk_main ();
 
